# Installing the Drupal Munin server

## 1. Install Munin and the module

The module is designed for Munin 1.4.4 and above. Use the normal Munin deployment
for your platform.

It is known to work, albeit with some warnings and limitations, on the older
Munin 1.2.6 (Ubuntu 9.04/Karmic).

On Debian/Ubuntu, you will find configuration in `/etc/munin`. 

- Install the module on Drupal, and enable the submodules you wish to use. 
- Default submodules are provided to monitor Drupal core (content, users), and
  the PHP APC opcode cache. 


## 2. Declare the plugin to Munin

A sample plugin is provided with the module as `plugins/munin-drupal_`, which
you can either use as such or customize as needed. The sample plugin uses `CURL`
to contact your Drupal site to obtain its data.

You will usually copy it to a directory in your `$PATH`, like `/usr/local/bin`,
or create a link to it from that directory, like:

```
ln -s <drupal>/sites/all/modules/munin_api/plugins/munin-drupal_ /usr/local/bin/munin-drupal_
```

## 3. Configure the plugin in Munin

Edit the `/etc/munin/plugin-conf/munin-node` file to declare the plugin.

Add a section for your plugin. If you are using the sample plugin provided with
the module, it needs to know the hostname of the site to monitor, which is not
always the same site as your Munin instance.
```ini
[drupal_*]
env.HOST mysitename.mydomain.tld
```


## 4. Check

Once declaration and configuration are done, you need to force `munin-node` to
update its configuration. On Ubuntu 10.10, for instance, use:

```
sudo service munin-node reload
```

Assuming you enabled Drupal core and APC monitoring. You can then check the module configuration:

```
munin-run drupal_core config
munin-run drupal_apc config  
```  
Then check their data:
 
```
munin-run drupal_core
munin-run drupal_apc  
```

  
## 5. Modify configuration

Any time you enable/disable a Munin submodule or modify its settings, you will
need to force a `munin-node` configuration reload so that the server knows what
to plot.


## 6. Access control

In the Drupal UI:

- The Munin API settings form
  - is located at: `admin/config/munin_api`
  - is controlled by permission: `administer site configuration`
- The Munin report pages
  - start at: `admin/reports/munin_api`  
  - are controlled by permission: `access site reports`
